@@ -50,7 +50,7 @@ from . import openshot_rc  # noqa
 DEFAULT_THEME_NAME = "Humanity"
 
 
-def load_theme():
+def load_icon_theme():
     """ Load the current OS theme, or fallback to a default one """
 
     s = get_app().get_settings()
@@ -130,6 +130,9 @@ def make_dark_palette(darkPalette: QPalette) -> QPalette:
     # Tooltips
     darkPalette.setColor(QPalette.ToolTipBase, QColor(42, 130, 218))
     darkPalette.setColor(QPalette.ToolTipText, Qt.white)
+    # Links
+    darkPalette.setColor(QPalette.Link, QColor(85, 170, 255))
+    darkPalette.setColor(QPalette.LinkVisited, QColor(136, 85, 255))
 
     return darkPalette
 
@@ -250,10 +253,26 @@ def connect_auto_events(window, elem, name):
     if hasattr(elem, 'trigger'):
         func_name = name + "_trigger"
         if hasattr(window, func_name) and callable(getattr(window, func_name)):
+            # Disconnect existing connections safely
+            try:
+                while True:
+                    elem.triggered.disconnect()
+            except TypeError:
+                pass  # No more connections to disconnect
+            # Connect the signal to the slot
             elem.triggered.connect(getattr(window, func_name))
+
+    # Similar approach for clicked signal
     if hasattr(elem, 'click'):
         func_name = name + "_click"
         if hasattr(window, func_name) and callable(getattr(window, func_name)):
+            # Disconnect existing connections safely
+            try:
+                while True:
+                    elem.clicked.disconnect()
+            except TypeError:
+                pass  # No more connections to disconnect
+            # Connect the signal to the slot
             elem.clicked.connect(getattr(window, func_name))
 
 
