@@ -238,7 +238,7 @@ with open(emoji_metadata_path, 'r', encoding="utf-8") as f:
 
 # Loop through the Blender XML
 blender_text = { "translator-credits": "Translator credits to be translated by LaunchPad" }
-blender_ignore_keys = ("Title", "Alpha", "Blur")
+blender_ignore_keys = ("Title", "Alpha", "Blur", "Font Name", "Yes", "No", "On", "Off", "Default")
 for file in os.listdir(blender_path):
     if os.path.isfile(os.path.join(blender_path, file)):
         # load xml effect file
@@ -260,6 +260,15 @@ for file in os.listdir(blender_path):
                 if translation_key not in blender_ignore_keys:
                     blender_text[param.attributes["title"].value] = full_file_path
 
+                    # Loop through child nodes of each param
+                    for child in param.childNodes:
+                        if child.nodeName == "values":
+                            for value in child.getElementsByTagName("value"):
+                                if value.hasAttribute("name"):
+                                    value_name = value.getAttribute("name")
+                                    if value_name not in blender_ignore_keys:
+                                        blender_text[value_name] = full_file_path
+
 # Loop through the Export Settings XML
 export_text = {}
 for file in os.listdir(export_path):
@@ -290,6 +299,11 @@ for setting in settings:
             for value in setting.get("values", []):
                 export_text[value["name"]] = "Settings for %s" % setting["setting"]
 
+# Include UI Theme Names (for translation)
+from themes.manager import ThemeName
+for theme_name in ThemeName.get_sorted_theme_names():
+    export_text[theme_name] = "User-Interface Theme Name"
+
 # Loop through transitions and add to POT file
 transitions_text = { "translator-credits": "Translator credits to be translated by LaunchPad" }
 transitions_ignore_keys = ("Common", "Fade")
