@@ -70,7 +70,7 @@ class PropertiesModel(updates.UpdateInterface):
     def changed(self, action):
 
         # Handle change
-        if action.key and action.key[0] in ["clips", "effects"] and action.type in ["update", "insert"]:
+        if len(action.key) >= 1 and action.key[0] in ["clips", "effects"] and action.type in ["update", "insert"]:
             log.debug(action.values)
             # Update the model data
             self.update_model(get_app().window.txtPropertyFilter.text())
@@ -516,6 +516,23 @@ class PropertiesModel(updates.UpdateInterface):
                 # Check the type of property (some are keyframe, and some are not)
                 if property_type != "reader" and isinstance(clip_data[property_key], dict):
                     # Keyframe
+
+                    # Protection from HUGE scale values
+                    if property_key in ['scale_x', 'scale_y', 'shear_x', 'shear_y'] and new_value:
+                        width = get_app().project.get("width")
+                        height = get_app().project.get("height")
+                        is_svg = clip_data.get("reader", {}).get("path", "").lower().endswith("svg")
+                        if is_svg:
+                            max_multiple = 15
+                        else:
+                            max_multiple = 50
+                        if width > 0 and height > 0:
+                            # Clamp the max scale based on project size
+                            max_multiple = round((2000 * max_multiple) / max(width, height))
+
+                        # Apply the calculated max_multiple to new_value
+                        new_value = max(min(new_value, max_multiple), -max_multiple)
+
                     # Loop through points, find a matching points on this frame
                     found_point = False
                     point_to_delete = None
@@ -607,7 +624,7 @@ class PropertiesModel(updates.UpdateInterface):
                 elif property_type == "string":
                     clip_updated = True
                     try:
-                        clip_data[property_key] = str(new_value)
+                        clip_data[property_key] = str(new_value or "")
                     except Exception:
                         log.warn('Invalid String value passed to property', exc_info=1)
 
@@ -685,7 +702,9 @@ class PropertiesModel(updates.UpdateInterface):
 
         selected_choice = None
         if choices:
-            selected_choice = [c for c in choices if c["selected"] is True][0]["name"]
+            selected_choices = [c for c in choices if c.get("selected") is True]
+            if selected_choices:
+                selected_choice = selected_choices[0]["name"]
 
         # Hide filtered out properties
         if filter and filter.lower() not in _(label).lower():
@@ -902,8 +921,17 @@ class PropertiesModel(updates.UpdateInterface):
 
             # Get raw unordered JSON properties
             raw_properties = json.loads(c.PropertiesJSON(self.frame_number))
-            objects_raw_properties = raw_properties.pop('objects', None)
 
+            # If a tracked object is found in this list, insert those properties as well
+            tracked_object_id = None
+            tracked_object_properties = {}
+            tracked_objects_raw_properties = raw_properties.pop('objects', None)
+            if tracked_objects_raw_properties:
+                tracked_object_id = list(tracked_objects_raw_properties.keys())[0]
+                tracked_object_properties = tracked_objects_raw_properties[tracked_object_id]
+                raw_properties.update(tracked_object_properties)
+
+            # Sort all properties (by 'name')
             all_properties = OrderedDict(sorted(raw_properties.items(), key=lambda x: x[1]['name']))
 
             # Check if filter was changed (if so, wipe previous model data)
@@ -928,14 +956,12 @@ class PropertiesModel(updates.UpdateInterface):
 
             # Loop through properties, and build a model
             for property in all_properties.items():
-                self.set_property(property, filter, c, item_type)
-
-            # Insert objects properties from custom effects
-            if objects_raw_properties:
-                for obj_id in objects_raw_properties:
-                    objects_all_properties = OrderedDict(sorted(objects_raw_properties[obj_id].items(), key=lambda x: x[1]['name']))
-                    for property in objects_all_properties.items():
-                        self.set_property(property, filter, c, item_type, object_id=obj_id)
+                if property[0] in tracked_object_properties:
+                    # Add tracked object property
+                    self.set_property(property, filter, c, item_type, object_id=tracked_object_id)
+                else:
+                    # Add base property
+                    self.set_property(property, filter, c, item_type)
 
             # Update the values on the next call to this method (instead of adding rows)
             self.new_item = False
