@@ -52,7 +52,7 @@ class VideoWidget(QWidget, updates.UpdateInterface):
     # This method is invoked by the UpdateManager each time a change happens (i.e UpdateInterface)
     def changed(self, action):
         # Handle change
-        if (action.key and action.key[0] in [
+        if (len(action.key) >= 1 and action.key[0] in [
                 "display_ratio", "pixel_ratio"
                 ] or action.type in ["load"]):
             # Update display ratio (if found)
@@ -329,8 +329,9 @@ class VideoWidget(QWidget, updates.UpdateInterface):
             | QPainter.TextAntialiasing,
             True)
 
-        # Fill the whole widget with the solid color
-        painter.fillRect(event.rect(), QColor("#191919"))
+        # Get theme colors (if any)
+        background_color = self.palette().color(self.backgroundRole())
+        painter.fillRect(event.rect(), background_color)
 
         # Find centered viewport
         viewport_rect = self.centeredViewport(self.width(), self.height())
@@ -349,7 +350,7 @@ class VideoWidget(QWidget, updates.UpdateInterface):
             # Calculate center of QWidget and Draw image
             painter.drawImage(viewport_rect, scaledPix)
 
-        if self.transforming_clip:
+        if self.transforming_clip and self.transforming_clip_object:
             # Draw transform handles on top of video preview
             # Get framerate
             fps = get_app().project.get("fps")
@@ -1431,6 +1432,10 @@ class VideoWidget(QWidget, updates.UpdateInterface):
         self.leftHandle = None
         self.rightHandle = None
         self.centerHandle = None
+        self.topShearHandle = None
+        self.leftShearHandle = None
+        self.rightShearHandle = None
+        self.bottomShearHandle = None
         self.clipBounds = None
         self.originHandle = None
         self.mouse_pressed = False
